/*
** Module   : ToggleBoxConfig.java
** Abstract : ToggleBox widget configuration.
**
** Copyright (c) 2010-2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 SVL 20101004 Created initial version.
** 002 SIY 20111101 Moved from CHUI package. Minor 
**                  cleanups/refactorings in preparation to GUI client.
** 003 EVL 20140609 Adding CHECKED attribute.
*/

package com.goldencode.p2j.ui;

import com.goldencode.p2j.ui.client.*;
import com.goldencode.p2j.ui.client.widget.*;

/**
 * ToggleBox widget configuration.
 */
public class ToggleBoxConfig
extends ControlConfig
{
   /** Progress CHECKED attribute. */
   private boolean checked = false;
   
   /**
    * Default constructor.
    */
   public ToggleBoxConfig()
   {
   }

   /**
    * Create empty configuration with all default values.
    *
    * @param   type
    *          Type of the new configuration.
    */
   public ToggleBoxConfig(int type)
   {
      super(type, null);
      setDcolor(Color.NORMAL);
      setPfcolor(Color.MESSAGES);
   }

   /**
    * Create an instance from other config. References to other widgets
    * are also restored.
    * 
    * @param   instance
    *          Instance to connect.
    * @param   cfg
    *          Instance to copy data from.
    */
   public ToggleBoxConfig(Widget instance, ComponentConfig cfg)
   {
      super(instance, cfg);
      setDcolor(Color.NORMAL);
      setPfcolor(Color.MESSAGES);
   }

   /**
    * Create empty configuration with all default values.
    * 
    * @param   type
    *          Type of the new configuration.
    * @param   instance
    *          A component to which this instance will be attached.
    */
   public ToggleBoxConfig(int type, ToggleBox instance)
   {
      super(type, instance);
      setDcolor(Color.NORMAL);
      setPfcolor(Color.MESSAGES);
   }
   
   /**
    * Set new values from the provided config instance.
    * 
    * @param   config
    *          Instance to take values from.
    */
   @Override
   public void applyConfig(ComponentConfig config)
   {
      super.applyConfig(config);

      if (config instanceof ToggleBoxConfig)
      {
         ToggleBoxConfig other = (ToggleBoxConfig) config;
         
//         setAutoEndKey(other.autoEndKey);
//         setAutoGo(other.autoGo);
//         setDefault(other.isDefault);
      }
   }   

   /**
    * Gets the CHECKED writable attribute.
    *
    * @return    The current value of the CHECKED attribute.
    */
   public boolean isChecked()
   {
      return checked;
   }

   /**
    * Set CHECKED attribute value.
    * 
    * @param   checked
    *          New value for the attribute.
    */
   public void setChecked(boolean checked)
   {
      this.checked = checked;
   }
}
